summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmdensityedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmdensityedit.h')
-rw-r--r--kpovmodeler/pmdensityedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmdensityedit.h b/kpovmodeler/pmdensityedit.h
index a3963ca9..a8241117 100644
--- a/kpovmodeler/pmdensityedit.h
+++ b/kpovmodeler/pmdensityedit.h
@@ -34,12 +34,13 @@ class PMDensity;
class PMDensityEdit : public PMTextureBaseEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMTextureBaseEdit Base;
public:
/**
* Creates a PMDensityEdit with parent and name
*/
- PMDensityEdit( TQWidget* parent, const char* name = 0 );
+ PMDensityEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -34,12 +34,13 @@ class PMDensity;
public:
/**
- * Creates a PMDensityEdit with parent and name
+ * Creates a PMDensityEdit with tqparent and name
*/